Crate solana_native_sigverify

Crate solana_native_sigverify 

Utilities for creating and parsing native signature verification program instruction data.

Solana runtime provides native programs for performing signature verification (henceforth referred to as native signature verification programs). Unfortunately, interface for interfacing with those programs is rather lacking.

This crate offers functions for creating instruction calling the native signature verification programs as well as parsing their instruction data.

Structs

BadData
Entry
A parse signature from the Ed25519 native program.
Iter
Iterator over signatures present in native signature verification program instruction data.
SignatureOffsets
Offsets used in instruction data of native signature verification programs.

Enums

Error
Error when parsing a signature.

Constants

ED25519_PROGRAM_ID
Address of the Ed25519 native program.
SECP256K1_PROGRAM_ID
Address of the Secp255k1 native program.
SECP256R1_PROGRAM_ID
Address of the Secp255r1 native program.

Functions

new_instruction
Creates an instruction calling a native signature verification program.
new_instruction_data
Creates instruction data for a call of a native signature verification program.
parse_data
Creates a new iterator over signatures in given native signature verification program instruction data.