pub enum Error {
UnsupportedFeature,
BadData,
}Expand description
Error when parsing a signature.
Variants
UnsupportedFeature
Signature entry references data from other instructions which is currently unsupported.
BadData
Signature entry is malformed.
Such entries should cause the native signature verification program instruction to fail so this should never happen when parsing past instructions of current transaction.